@@ -1,4 +1,4 @@
-#define NLANGUAGES 1133
+#define NLANGUAGES 1142
 struct LanguageScripts
 {
   const gchar *language;
@@ -158,7 +158,8 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "chm", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "chn", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cho", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "chp", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
+    { "chp", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "chp_CA", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
     { "chr", { N_("Cherokee"), NULL }, { 0x43686572, 0 } },
     { "chy", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cic", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -168,10 +169,12 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "ckb_IQ", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "ckb_IR", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "ckt", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
+    { "clc", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "co", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cop", { N_("Arabic"), N_("Coptic"), N_("Greek"), NULL }, { 0x41726162, 0x436f7074, 0x4772656b, 0 } },
     { "cps", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cr", { N_("Canadian_Aboriginal"), N_("Latin"), NULL }, { 0x43616e73, 0x4c61746e, 0 } },
+    { "crg", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "crh", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "crj", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "crk", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
@@ -210,7 +213,8 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "de_SK", { N_("Runic"), NULL }, { 0x52756e72, 0 } },
     { "de_US", { N_("Runic"), NULL }, { 0x52756e72, 0 } },
     { "del", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "den", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
+    { "den", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "den_CA", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
     { "dgr", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "din", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "dje", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -324,6 +328,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "en_MS", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_MT", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_MU", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "en_MV", { N_("Deseret"), N_("Shavian"), NULL }, { 0x44737274, 0x53686177, 0 } },
     { "en_MW", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_MX", { N_("Deseret"), N_("Shavian"), NULL }, { 0x44737274, 0x53686177, 0 } },
     { "en_MY", { N_("Deseret"), N_("Shavian"), NULL }, { 0x44737274, 0x53686177, 0 } },
@@ -544,7 +549,6 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "hnd", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "hne", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "hnj", { N_("Lao"), NULL }, { 0x4c616f6f, 0 } },
-    { "hnj_US", { N_("Nyiakeng_Puachue_Hmong"), NULL }, { 0x486d6e70, 0 } },
     { "hnn", { N_("Hanunoo"), NULL }, { 0x48616e6f, 0 } },
     { "hno", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "ho_PG", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -559,6 +563,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "ht_HT", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "hu_HU", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "hup", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "hur", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "hy_AM", { N_("Armenian"), NULL }, { 0x41726d6e, 0 } },
     { "hz", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ia", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -656,6 +661,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "kvr", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kvx", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "kw", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "kwk", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kxm", { N_("Thai"), NULL }, { 0x54686169, 0 } },
     { "kxp", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "ky_KG", { N_("Arabic"), N_("Cyrillic"), N_("Latin"), NULL }, { 0x41726162, 0x4379726c, 0x4c61746e, 0 } },
@@ -679,6 +685,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "li", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lif", { N_("Devanagari"), N_("Limbu"), NULL }, { 0x44657661, 0x4c696d62, 0 } },
     { "lij", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "lil", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lis", { N_("Lisu"), NULL }, { 0x4c697375, 0 } },
     { "liv", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ljp", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -802,7 +809,6 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "nn_NO", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "nnh", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "no_NO", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "no_SJ", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "nod", { N_("Tai_Tham"), NULL }, { 0x4c616e61, 0 } },
     { "noe", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "nog", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
@@ -822,6 +828,8 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "nzi", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "oc", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "oj", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "ojs", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
+    { "oka", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "om", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "om_ET", { N_("Ethiopic"), NULL }, { 0x45746869, 0 } },
     { "or", { N_("Oriya"), NULL }, { 0x4f727961, 0 } },
@@ -849,6 +857,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "pms", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "pnt", { N_("Cyrillic"), N_("Greek"), N_("Latin"), NULL }, { 0x4379726c, 0x4772656b, 0x4c61746e, 0 } },
     { "pon", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "pqm", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "prd", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "prg", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "pro", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
